# Changelog

All notable changes to this project will be documented in this file

## Version 0.1.3 - 2021-05-13

### Changed

- Updated to support Click version 8
- Minor metadata changes


## Version 0.1.2 - 2021-04-13

### Added

- new `--verbose` command line option that prints the input and output path for each file


## Version 0.1.1 - 2021-04-12

### Added

- First stable release